@@ -11,6 +11,7 @@ from tornado.httpclient import AsyncHTTPClient
 import redis
 from materialgirl import Materializer
 from materialgirl.storage.redis import RedisStorage
+import tornado
 
 from holmes.handlers.worker import WorkerHandler, WorkersHandler, WorkersInfoHandler
 from holmes.handlers.worker_state import WorkerStateHandler
@@ -45,6 +46,7 @@ from holmes.utils import load_classes
 from holmes.models import Key
 from holmes.models import KeysCategory
 from holmes.cache import Cache
+from holmes import __version__
 
 
 def main():
@@ -52,6 +54,11 @@ def main():
     HolmesApiServer.run()
 
 
+class VersionHandler(tornado.web.RequestHandler):
+    def get(self):
+        self.write(__version__)
+
+
 class HolmesApiServer(Server):
     def __init__(self, db=None, debug=None, *args, **kw):
         super(HolmesApiServer, self).__init__(*args, **kw)
@@ -103,6 +110,7 @@ class HolmesApiServer(Server):
             (r'/limiters/?', LimiterHandler),
             (r'/next-jobs/?', NextJobHandler),
             (r'/last-requests/?', LastRequestsHandler),
+            (r'/version/?', VersionHandler),
         ]
 
         return tuple(handlers)
@@ -146,7 +154,7 @@ class HolmesApiServer(Server):
 
         self.application.cache = Cache(self.application)
 
-        self.configure_material_girl()
+        #self.configure_material_girl()
 
     def configure_material_girl(self):
         from holmes.material import configure_materials
